/**
 * MaterialDesign icon set component.
 * Usage: <MaterialDesign name="icon-name" size={20} color="#4F8EF7" />
 *
 * @providesModule MaterialDesign
 */
'use strict';

var createIconSet = require('./').createIconSet;
var glyphMap = {
  "3d-rotation": 61440,
  "accessibility": 61441,
  "account-balance": 61442,
  "account-balance-wallet": 61443,
  "account-box": 61444,
  "account-child": 61445,
  "account-circle": 61446,
  "add-shopping-cart": 61447,
  "alarm": 61448,
  "alarm-add": 61449,
  "alarm-off": 61450,
  "alarm-on": 61451,
  "android": 61452,
  "announcement": 61453,
  "aspect-ratio": 61454,
  "assessment": 61455,
  "assignment": 61456,
  "assignment-ind": 61457,
  "assignment-late": 61458,
  "assignment-return": 61459,
  "assignment-returned": 61460,
  "assignment-turned-in": 61461,
  "autorenew": 61462,
  "backup": 61463,
  "book": 61464,
  "bookmark": 61465,
  "bookmark-outline": 61466,
  "bug-report": 61467,
  "cached": 61468,
  "class": 61469,
  "credit-card": 61470,
  "dashboard": 61471,
  "delete": 61472,
  "description": 61473,
  "dns": 61474,
  "done": 61475,
  "done-all": 61476,
  "event": 61477,
  "exit-to-app": 61478,
  "explore": 61479,
  "extension": 61480,
  "face-unlock": 61481,
  "favorite": 61482,
  "favorite-outline": 61483,
  "find-in-page": 61484,
  "find-replace": 61485,
  "flip-to-back": 61486,
  "flip-to-front": 61487,
  "get-app": 61488,
  "grade": 61489,
  "group-work": 61490,
  "help": 61491,
  "highlight-remove": 61492,
  "history": 61493,
  "home": 61494,
  "https": 61495,
  "info": 61496,
  "info-outline": 61497,
  "input": 61498,
  "invert-colors": 61499,
  "label": 61500,
  "label-outline": 61501,
  "language": 61502,
  "launch": 61503,
  "list": 61504,
  "lock": 61505,
  "lock-open": 61506,
  "lock-outline": 61507,
  "loyalty": 61508,
  "markunread-mailbox": 61509,
  "note-add": 61510,
  "open-in-browser": 61511,
  "open-in-new": 61512,
  "open-with": 61513,
  "pageview": 61514,
  "payment": 61515,
  "perm-camera-mic": 61516,
  "perm-contact-cal": 61517,
  "perm-data-setting": 61518,
  "perm-device-info": 61519,
  "perm-identity": 61520,
  "perm-media": 61521,
  "perm-phone-msg": 61522,
  "perm-scan-wifi": 61523,
  "picture-in-picture": 61524,
  "polymer": 61525,
  "print": 61526,
  "query-builder": 61527,
  "question-answer": 61528,
  "receipt": 61529,
  "redeem": 61530,
  "report-problem": 61531,
  "restore": 61532,
  "room": 61533,
  "schedule": 61534,
  "search": 61535,
  "settings": 61536,
  "settings-applications": 61537,
  "settings-backup-restore": 61538,
  "settings-bluetooth": 61539,
  "settings-cell": 61540,
  "settings-display": 61541,
  "settings-ethernet": 61542,
  "settings-input-antenna": 61543,
  "settings-input-component": 61544,
  "settings-input-composite": 61545,
  "settings-input-hdmi": 61546,
  "settings-input-svideo": 61547,
  "settings-overscan": 61548,
  "settings-phone": 61549,
  "settings-power": 61550,
  "settings-remote": 61551,
  "settings-voice": 61552,
  "shop": 61553,
  "shopping-basket": 61554,
  "shopping-cart": 61555,
  "shop-two": 61556,
  "speaker-notes": 61557,
  "spellcheck": 61558,
  "star-rate": 61559,
  "stars": 61560,
  "store": 61561,
  "subject": 61562,
  "swap-horiz": 61563,
  "swap-vert": 61564,
  "swap-vert-circle": 61565,
  "system-update-tv": 61566,
  "tab": 61567,
  "tab-unselected": 61568,
  "theaters": 61569,
  "thumb-down": 61570,
  "thumbs-up-down": 61571,
  "thumb-up": 61572,
  "toc": 61573,
  "today": 61574,
  "track-changes": 61575,
  "translate": 61576,
  "trending-down": 61577,
  "trending-neutral": 61578,
  "trending-up": 61579,
  "turned-in": 61580,
  "turned-in-not": 61581,
  "verified-user": 61582,
  "view-agenda": 61583,
  "view-array": 61584,
  "view-carousel": 61585,
  "view-column": 61586,
  "view-day": 61587,
  "view-headline": 61588,
  "view-list": 61589,
  "view-module": 61590,
  "view-quilt": 61591,
  "view-stream": 61592,
  "view-week": 61593,
  "visibility": 61594,
  "visibility-off": 61595,
  "wallet-giftcard": 61596,
  "wallet-membership": 61597,
  "wallet-travel": 61598,
  "work": 61599,
  "error": 61600,
  "warning": 61601,
  "album": 61602,
  "av-timer": 61603,
  "closed-caption": 61604,
  "equalizer": 61605,
  "explicit": 61606,
  "fast-forward": 61607,
  "fast-rewind": 61608,
  "games": 61609,
  "hearing": 61610,
  "high-quality": 61611,
  "loop": 61612,
  "mic": 61613,
  "mic-none": 61614,
  "mic-off": 61615,
  "movie": 61616,
  "my-library-add": 61617,
  "my-library-books": 61618,
  "my-library-music": 61619,
  "new-releases": 61620,
  "not-interested": 61621,
  "pause": 61622,
  "pause-circle-fill": 61623,
  "pause-circle-outline": 61624,
  "play-arrow": 61625,
  "play-circle-fill": 61626,
  "play-circle-outline": 61627,
  "playlist-add": 61628,
  "play-shopping-bag": 61629,
  "queue": 61630,
  "queue-music": 61631,
  "radio": 61632,
  "recent-actors": 61633,
  "repeat": 61634,
  "repeat-one": 61635,
  "replay": 61636,
  "shuffle": 61637,
  "skip-next": 61638,
  "skip-previous": 61639,
  "snooze": 61640,
  "stop": 61641,
  "subtitles": 61642,
  "surround-sound": 61643,
  "videocam": 61644,
  "videocam-off": 61645,
  "video-collection": 61646,
  "volume-down": 61647,
  "volume-mute": 61648,
  "volume-off": 61649,
  "volume-up": 61650,
  "web": 61651,
  "business": 61652,
  "call": 61653,
  "call-end": 61654,
  "call-made": 61655,
  "call-merge": 61656,
  "call-missed": 61657,
  "call-received": 61658,
  "call-split": 61659,
  "chat": 61660,
  "clear-all": 61661,
  "comment": 61662,
  "contacts": 61663,
  "dialer-sip": 61664,
  "dialpad": 61665,
  "dnd-on": 61666,
  "email": 61667,
  "forum": 61668,
  "import-export": 61669,
  "invert-colors-off": 61670,
  "invert-colors-on": 61671,
  "live-help": 61672,
  "location-off": 61673,
  "location-on": 61674,
  "message": 61675,
  "messenger": 61676,
  "no-sim": 61677,
  "phone": 61678,
  "portable-wifi-off": 61679,
  "quick-contacts-dialer": 61680,
  "quick-contacts-mail": 61681,
  "ring-volume": 61682,
  "stay-current-landscape": 61683,
  "stay-current-portrait": 61684,
  "stay-primary-landscape": 61685,
  "stay-primary-portrait": 61686,
  "swap-calls": 61687,
  "textsms": 61688,
  "voicemail": 61689,
  "vpn-key": 61690,
  "add": 61691,
  "add-box": 61692,
  "add-circle": 61693,
  "add-circle-outline": 61694,
  "archive": 61695,
  "backspace": 61696,
  "block": 61697,
  "clear": 61698,
  "content-copy": 61699,
  "content-cut": 61700,
  "content-paste": 61701,
  "create": 61702,
  "drafts": 61703,
  "filter-list": 61704,
  "flag": 61705,
  "forward": 61706,
  "gesture": 61707,
  "inbox": 61708,
  "link": 61709,
  "mail": 61710,
  "markunread": 61711,
  "redo": 61712,
  "remove": 61713,
  "remove-circle": 61714,
  "remove-circle-outline": 61715,
  "reply": 61716,
  "reply-all": 61717,
  "report": 61718,
  "save": 61719,
  "select-all": 61720,
  "send": 61721,
  "sort": 61722,
  "text-format": 61723,
  "undo": 61724,
  "access-alarm": 61725,
  "access-alarms": 61726,
  "access-time": 61727,
  "add-alarm": 61728,
  "airplanemode-off": 61729,
  "airplanemode-on": 61730,
  "battery-20": 61731,
  "battery-30": 61732,
  "battery-50": 61733,
  "battery-60": 61734,
  "battery-80": 61735,
  "battery-90": 61736,
  "battery-alert": 61737,
  "battery-charging-20": 61738,
  "battery-charging-30": 61739,
  "battery-charging-50": 61740,
  "battery-charging-60": 61741,
  "battery-charging-80": 61742,
  "battery-charging-90": 61743,
  "battery-charging-full": 61744,
  "battery-full": 61745,
  "battery-std": 61746,
  "battery-unknown": 61747,
  "bluetooth": 61748,
  "bluetooth-connected": 61749,
  "bluetooth-disabled": 61750,
  "bluetooth-searching": 61751,
  "brightness-auto": 61752,
  "brightness-high": 61753,
  "brightness-low": 61754,
  "brightness-medium": 61755,
  "data-usage": 61756,
  "developer-mode": 61757,
  "devices": 61758,
  "dvr": 61759,
  "gps-fixed": 61760,
  "gps-not-fixed": 61761,
  "gps-off": 61762,
  "location-disabled": 61763,
  "location-searching": 61764,
  "multitrack-audio": 61765,
  "network-cell": 61766,
  "network-wifi": 61767,
  "nfc": 61768,
  "now-wallpaper": 61769,
  "now-widgets": 61770,
  "screen-lock-landscape": 61771,
  "screen-lock-portrait": 61772,
  "screen-lock-rotation": 61773,
  "screen-rotation": 61774,
  "sd-storage": 61775,
  "settings-system-daydream": 61776,
  "signal-cellular-0-bar": 61777,
  "signal-cellular-1-bar": 61778,
  "signal-cellular-2-bar": 61779,
  "signal-cellular-3-bar": 61780,
  "signal-cellular-4-bar": 61781,
  "signal-cellular-connected-no-internet-0-bar": 61782,
  "signal-cellular-connected-no-internet-1-bar": 61783,
  "signal-cellular-connected-no-internet-2-bar": 61784,
  "signal-cellular-connected-no-internet-3-bar": 61785,
  "signal-cellular-connected-no-internet-4-bar": 61786,
  "signal-cellular-no-sim": 61787,
  "signal-cellular-null": 61788,
  "signal-cellular-off": 61789,
  "signal-wifi-0-bar": 61790,
  "signal-wifi-1-bar": 61791,
  "signal-wifi-2-bar": 61792,
  "signal-wifi-3-bar": 61793,
  "signal-wifi-4-bar": 61794,
  "signal-wifi-off": 61795,
  "storage": 61796,
  "usb": 61797,
  "wifi-lock": 61798,
  "wifi-tethering": 61799,
  "attach-file": 61800,
  "attach-money": 61801,
  "border-all": 61802,
  "border-bottom": 61803,
  "border-clear": 61804,
  "border-color": 61805,
  "border-horizontal": 61806,
  "border-inner": 61807,
  "border-left": 61808,
  "border-outer": 61809,
  "border-right": 61810,
  "border-style": 61811,
  "border-top": 61812,
  "border-vertical": 61813,
  "format-align-center": 61814,
  "format-align-justify": 61815,
  "format-align-left": 61816,
  "format-align-right": 61817,
  "format-bold": 61818,
  "format-clear": 61819,
  "format-color-fill": 61820,
  "format-color-reset": 61821,
  "format-color-text": 61822,
  "format-indent-decrease": 61823,
  "format-indent-increase": 61824,
  "format-italic": 61825,
  "format-line-spacing": 61826,
  "format-list-bulleted": 61827,
  "format-list-numbered": 61828,
  "format-paint": 61829,
  "format-quote": 61830,
  "format-size": 61831,
  "format-strikethrough": 61832,
  "format-textdirection-l-to-r": 61833,
  "format-textdirection-r-to-l": 61834,
  "format-underline": 61835,
  "functions": 61836,
  "insert-chart": 61837,
  "insert-comment": 61838,
  "insert-drive-file": 61839,
  "insert-emoticon": 61840,
  "insert-invitation": 61841,
  "insert-link": 61842,
  "insert-photo": 61843,
  "merge-type": 61844,
  "mode-comment": 61845,
  "mode-edit": 61846,
  "publish": 61847,
  "vertical-align-bottom": 61848,
  "vertical-align-center": 61849,
  "vertical-align-top": 61850,
  "wrap-text": 61851,
  "attachment": 61852,
  "cloud": 61853,
  "cloud-circle": 61854,
  "cloud-done": 61855,
  "cloud-download": 61856,
  "cloud-off": 61857,
  "cloud-queue": 61858,
  "cloud-upload": 61859,
  "file-download": 61860,
  "file-upload": 61861,
  "folder": 61862,
  "folder-open": 61863,
  "folder-shared": 61864,
  "cast": 61865,
  "cast-connected": 61866,
  "computer": 61867,
  "desktop-mac": 61868,
  "desktop-windows": 61869,
  "dock": 61870,
  "gamepad": 61871,
  "headset": 61872,
  "headset-mic": 61873,
  "keyboard": 61874,
  "keyboard-alt": 61875,
  "keyboard-arrow-down": 61876,
  "keyboard-arrow-left": 61877,
  "keyboard-arrow-right": 61878,
  "keyboard-arrow-up": 61879,
  "keyboard-backspace": 61880,
  "keyboard-capslock": 61881,
  "keyboard-control": 61882,
  "keyboard-hide": 61883,
  "keyboard-return": 61884,
  "keyboard-tab": 61885,
  "keyboard-voice": 61886,
  "laptop": 61887,
  "laptop-chromebook": 61888,
  "laptop-mac": 61889,
  "laptop-windows": 61890,
  "memory": 61891,
  "mouse": 61892,
  "phone-android": 61893,
  "phone-iphone": 61894,
  "phonelink": 61895,
  "phonelink-off": 61896,
  "security": 61897,
  "sim-card": 61898,
  "smartphone": 61899,
  "speaker": 61900,
  "tablet": 61901,
  "tablet-android": 61902,
  "tablet-mac": 61903,
  "tv": 61904,
  "watch": 61905,
  "add-to-photos": 61906,
  "adjust": 61907,
  "assistant-photo": 61908,
  "audiotrack": 61909,
  "blur-circular": 61910,
  "blur-linear": 61911,
  "blur-off": 61912,
  "blur-on": 61913,
  "brightness-1": 61914,
  "brightness-2": 61915,
  "brightness-3": 61916,
  "brightness-4": 61917,
  "brightness-5": 61918,
  "brightness-6": 61919,
  "brightness-7": 61920,
  "brush": 61921,
  "camera": 61922,
  "camera-alt": 61923,
  "camera-front": 61924,
  "camera-rear": 61925,
  "camera-roll": 61926,
  "center-focus-strong": 61927,
  "center-focus-weak": 61928,
  "collections": 61929,
  "colorize": 61930,
  "color-lens": 61931,
  "compare": 61932,
  "control-point": 61933,
  "control-point-duplicate": 61934,
  "crop": 61935,
  "crop-3-2": 61936,
  "crop-5-4": 61937,
  "crop-7-5": 61938,
  "crop-16-9": 61939,
  "crop-din": 61940,
  "crop-free": 61941,
  "crop-landscape": 61942,
  "crop-original": 61943,
  "crop-portrait": 61944,
  "crop-square": 61945,
  "dehaze": 61946,
  "details": 61947,
  "edit": 61948,
  "exposure": 61949,
  "exposure-minus-1": 61950,
  "exposure-minus-2": 61951,
  "exposure-zero": 61952,
  "exposure-plus-1": 61953,
  "exposure-plus-2": 61954,
  "filter": 61955,
  "filter-1": 61956,
  "filter-2": 61957,
  "filter-3": 61958,
  "filter-4": 61959,
  "filter-5": 61960,
  "filter-6": 61961,
  "filter-7": 61962,
  "filter-8": 61963,
  "filter-9": 61964,
  "filter-9-plus": 61965,
  "filter-b-and-w": 61966,
  "filter-center-focus": 61967,
  "filter-drama": 61968,
  "filter-frames": 61969,
  "filter-hdr": 61970,
  "filter-none": 61971,
  "filter-tilt-shift": 61972,
  "filter-vintage": 61973,
  "flare": 61974,
  "flash-auto": 61975,
  "flash-off": 61976,
  "flash-on": 61977,
  "flip": 61978,
  "gradient": 61979,
  "grain": 61980,
  "grid-off": 61981,
  "grid-on": 61982,
  "hdr-off": 61983,
  "hdr-on": 61984,
  "hdr-strong": 61985,
  "hdr-weak": 61986,
  "healing": 61987,
  "image": 61988,
  "image-aspect-ratio": 61989,
  "iso": 61990,
  "landscape": 61991,
  "leak-add": 61992,
  "leak-remove": 61993,
  "lens": 61994,
  "looks": 61995,
  "looks-1": 61996,
  "looks-2": 61997,
  "looks-3": 61998,
  "looks-4": 61999,
  "looks-5": 62000,
  "looks-6": 62001,
  "loupe": 62002,
  "movie-creation": 62003,
  "nature": 62004,
  "nature-people": 62005,
  "navigate-before": 62006,
  "navigate-next": 62007,
  "palette": 62008,
  "panorama": 62009,
  "panorama-fisheye": 62010,
  "panorama-horizontal": 62011,
  "panorama-vertical": 62012,
  "panorama-wide-angle": 62013,
  "photo": 62014,
  "photo-album": 62015,
  "photo-camera": 62016,
  "photo-library": 62017,
  "portrait": 62018,
  "remove-red-eye": 62019,
  "rotate-left": 62020,
  "rotate-right": 62021,
  "slideshow": 62022,
  "straighten": 62023,
  "style": 62024,
  "switch-camera": 62025,
  "switch-video": 62026,
  "tag-faces": 62027,
  "texture": 62028,
  "timelapse": 62029,
  "timer": 62030,
  "timer-3": 62031,
  "timer-10": 62032,
  "timer-auto": 62033,
  "timer-off": 62034,
  "tonality": 62035,
  "transform": 62036,
  "tune": 62037,
  "wb-auto": 62038,
  "wb-cloudy": 62039,
  "wb-incandescent": 62040,
  "wb-irradescent": 62041,
  "wb-sunny": 62042,
  "beenhere": 62043,
  "directions": 62044,
  "directions-bike": 62045,
  "directions-bus": 62046,
  "directions-car": 62047,
  "directions-ferry": 62048,
  "directions-subway": 62049,
  "directions-train": 62050,
  "directions-transit": 62051,
  "directions-walk": 62052,
  "flight": 62053,
  "hotel": 62054,
  "layers": 62055,
  "layers-clear": 62056,
  "local-airport": 62057,
  "local-atm": 62058,
  "local-attraction": 62059,
  "local-bar": 62060,
  "local-cafe": 62061,
  "local-car-wash": 62062,
  "local-convenience-store": 62063,
  "local-drink": 62064,
  "local-florist": 62065,
  "local-gas-station": 62066,
  "local-grocery-store": 62067,
  "local-hospital": 62068,
  "local-hotel": 62069,
  "local-laundry-service": 62070,
  "local-library": 62071,
  "local-mall": 62072,
  "local-movies": 62073,
  "local-offer": 62074,
  "local-parking": 62075,
  "local-pharmacy": 62076,
  "local-phone": 62077,
  "local-pizza": 62078,
  "local-play": 62079,
  "local-post-office": 62080,
  "local-print-shop": 62081,
  "local-restaurant": 62082,
  "local-see": 62083,
  "local-shipping": 62084,
  "local-taxi": 62085,
  "location-history": 62086,
  "map": 62087,
  "my-location": 62088,
  "navigation": 62089,
  "pin-drop": 62090,
  "place": 62091,
  "rate-review": 62092,
  "restaurant-menu": 62093,
  "satellite": 62094,
  "store-mall-directory": 62095,
  "terrain": 62096,
  "traffic": 62097,
  "apps": 62098,
  "cancel": 62099,
  "arrow-drop-down-circle": 62100,
  "arrow-drop-down": 62101,
  "arrow-drop-up": 62102,
  "arrow-back": 62103,
  "arrow-forward": 62104,
  "check": 62105,
  "close": 62106,
  "chevron-left": 62107,
  "chevron-right": 62108,
  "expand-less": 62109,
  "expand-more": 62110,
  "fullscreen": 62111,
  "fullscreen-exit": 62112,
  "menu": 62113,
  "more-horiz": 62114,
  "more-vert": 62115,
  "refresh": 62116,
  "unfold-less": 62117,
  "unfold-more": 62118,
  "adb": 62119,
  "bluetooth-audio": 62120,
  "disc-full": 62121,
  "dnd-forwardslash": 62122,
  "do-not-disturb": 62123,
  "drive-eta": 62124,
  "event-available": 62125,
  "event-busy": 62126,
  "event-note": 62127,
  "folder-special": 62128,
  "mms": 62129,
  "more": 62130,
  "network-locked": 62131,
  "phone-bluetooth-speaker": 62132,
  "phone-forwarded": 62133,
  "phone-in-talk": 62134,
  "phone-locked": 62135,
  "phone-missed": 62136,
  "phone-paused": 62137,
  "play-download": 62138,
  "play-install": 62139,
  "sd-card": 62140,
  "sim-card-alert": 62141,
  "sms": 62142,
  "sms-failed": 62143,
  "sync": 62144,
  "sync-disabled": 62145,
  "sync-problem": 62146,
  "system-update": 62147,
  "tap-and-play": 62148,
  "time-to-leave": 62149,
  "vibration": 62150,
  "voice-chat": 62151,
  "vpn-lock": 62152,
  "cake": 62153,
  "domain": 62154,
  "location-city": 62155,
  "mood": 62156,
  "notifications-none": 62157,
  "notifications": 62158,
  "notifications-off": 62159,
  "notifications-on": 62160,
  "notifications-paused": 62161,
  "pages": 62162,
  "party-mode": 62163,
  "group": 62164,
  "group-add": 62165,
  "people": 62166,
  "people-outline": 62167,
  "person": 62168,
  "person-add": 62169,
  "person-outline": 62170,
  "plus-one": 62171,
  "poll": 62172,
  "public": 62173,
  "school": 62174,
  "share": 62175,
  "whatshot": 62176,
  "check-box": 62177,
  "check-box-outline-blank": 62178,
  "radio-button-off": 62179,
  "radio-button-on": 62180,
  "star": 62181,
  "star-half": 62182,
  "star-outline": 62183
};

var MaterialDesign = createIconSet(glyphMap, 'Material-Design-Iconic-Font');

module.exports = MaterialDesign;
module.exports.glyphMap = glyphMap;

